# Ridibooks CMS SDK - Python

## Requirements

- python 3.4 or higher

## Setup

`pip install ridi-cms-sdk`

## Usage

Check out our [sample project](https://github.com/ridi/cms-bootstrap-python) for more details.